#!/usr/bin/env python3

# script that generates patches from staging
# used in case the user does not have commit access to Debian git

import subprocess
import os

package_list = "package-name-lists/plasma-xenial"
with open(package_list, 'r') as fh:
  file_buffer = fh.read().splitlines()

repos_path = "/tmp/tmp4LzR5G/"

cwd = os.getcwd()

def error_continue(message = ""):
  if len(message) > 0:
    print(message)
  answer = input("Continue? [Y/n]")
  if len(answer) == 0:
    answer = "Y"
  answer = answer[0]
  if answer.upper() == "Y":
    return 0
  else:
    return -1

failed = []

for line in file_buffer:
  print("=======================================================================")
  print("Generating patch for " + line)
  print("=======================================================================")

  if not os.path.exists(repos_path + line + "/git"):
    error = error_continue("git repo for " + line + " not found in " + repos_path)
    failed.append(line)
    if error == -1:
      exit(1)
    else:
      continue
  else:
    os.chdir(repos_path + line + "/git")
    command = ["git", "show", "HEAD"]
    try:
      patch_buffer = subprocess.check_output(command)
      patch_file = repos_path + "patches/" + line + ".patch"
      print("Patch generated. Writing patch to: " + patch_file)
      if not os.path.exists(repos_path + "patches"):
        os.makedirs(repos_path + "patches")
      fh = open(patch_file, 'w')
      fh.write(patch_buffer.decode("utf-8"))
      fh.close()
    except subprocess.CalledProcessError as e:
      failed.append(line)
      print("Error generating patch for " + line + ".")
      print("Return code: " + str(e.returncode))
      print(e.output)
      if error_continue() == -1:
        exit(2)
      else:
        continue

print("Patches generated")
if len(failed) > 0:
  print("Failed to generate patches for:\n" + "\n".join(failed))
