#!/usr/bin/env python3

# Initial, very crude version of a reuploader script.


import subprocess
import os
import sys
import shutil

cwd = os.getcwd()
work_dir = cwd + "/tmp_work/"
build_area = work_dir + "build-area"

package_list = "package-name-lists/plasma-xenial"
branch = "kubuntu_xenial_archive"
build_command = [cwd + "/git-buildpackage-ppa", "-s", "10", "-d", "xenial", "-y", "16.04"]
upload_command = ["dput", "ppa:kubuntu-ppa/staging-plasma"]

def execute(command):
  print("-----------------------------------------------------------------------")
  print("Running:", command)
  try:
    subprocess.check_call(command)
    return 0
  except subprocess.CalledProcessError as e:
    print("FAILED to execute command", file=sys.stderr)
    print("Working directory: " + os.getcwd(), file=sys.stderr)
    print("Exit code " + str(e.returncode), file=sys.stderr)
    return -1

def cleanup():
  os.chdir(cwd)
  print("Cleaning up...")
  shutil.rmtree(build_area)
  shutil.rmtree(work_dir)

with open(package_list, 'r') as fh:
  file_buffer = fh.read().splitlines()

for line in file_buffer:
  print("=======================================================================")
  print("Rebuilding package " + line + "...")
  print("=======================================================================")
  command = ["git", "clone", "debian:pkg-kde/plasma/" + line, work_dir + line]
  return_code = execute(command)

  if return_code != -1:
    os.chdir(work_dir + line)
    command = ["git", "checkout", branch]
    return_code = execute(command)
    if return_code != -1:
      return_code = execute(build_command)

  if return_code != -1:
    os.chdir(build_area)
    files = []
    for filename in os.listdir(os.getcwd()):
      if filename.endswith(".changes"):
        files.append(filename)

    if len(list) > 0:
      command = list(upload_command) # copy upload_command in command
      command.extend(files) # add found files as arguments to command
      return_code = execute(command)

  if return_code == -1:
    answer = input("Continue? [Y/n]")
    if len(answer) == 0:
      answer = "Y"
    answer = answer[0]
    if answer.upper() == "Y":
      return_code = 0
    else:
      exit(1)

  if return_code != -1:
    cleanup()
