#!/usr/bin/python3
# -*- coding: utf-8 -*-
# kate: space-indent on; indent-width 4; replace-tabs on; indent-mode python; remove-trailing-space modified;
# vim: expandtab ts=4

############################################################################
#   Copyright © 2015-2016 José Manuel Santamaría Lema <panfaust@gmail.com> #
#                                                                          #
#   This program is free software; you can redistribute it and/or modify   #
#   it under the terms of the GNU General Public License as published by   #
#   the Free Software Foundation; either version 2 of the License, or      #
#   (at your option) any later version.                                    #
############################################################################

import os
import json
import configparser

#Returns a map with the configuration items present in the file
#DEPRECATED: use readConfigValue(...) instead
def readConfigFile(config_file_name):
    cwd = os.path.dirname(os.path.realpath(__file__))
    config_file = open(cwd + "/../conf/" + config_file_name)
    result = json.load(config_file)
    if config_file_name == "tarball-locations.json":
        #expand "~" in the tarball paths
        for i in result:
            result[i] = os.path.expanduser(result[i])
    return result

#Returns a configuration value, defaults to default_value
#DEPRECATED: use the parser given by getConfigParser
def readConfigValue(config_file_name, value, default_value=None):
    cwd = os.path.dirname(os.path.realpath(__file__))
    config_file = open(cwd + "/../conf/" + config_file_name)
    config_map = json.load(config_file)
    if config_file_name == "tarball-locations.json":
        #expand "~" in the tarball paths
        for i in config_map:
            config_map[i] = os.path.expanduser(result[i])
    try:
        return config_map[value]
    except:
        if default_value != None:
            return default_value
        else:
            print("No value %s set in configuration file %s found, aborting." % (value,config_file_name) )
            sys.exit(1)

#Returns a config parser with the KA configuration
def getConfigParser(create_template=False):
    #If we already got the configuration just return the current parser
    if hasattr(getConfigParser,'_config'):
        return getConfigParser._config
    #Init config parser
    getConfigParser._config = configparser.RawConfigParser()
    #Default config #1
    cwd = os.path.dirname(os.path.realpath(__file__))
    defaultconfig1 = cwd + '/../conf/defaultrc'
    getConfigParser._config.read(defaultconfig1)
    #Default config #2
    defaultconfig2 = os.path.join(cwd, 'defaultconfig/defaultrc')
    getConfigParser._config.read(defaultconfig2)
    #Default config #3 - System wide /etc file
    defaultconfig3 = os.path.join(cwd, '/etc/ka/kubuntu-automation.conf')
    getConfigParser._config.read(defaultconfig3)
    #User config
    userconfig = '~/.kubuntu-automation.conf'
    userconfig = os.path.expanduser(userconfig)
    getConfigParser._config.read(userconfig)
    #If the user config file doesn't exist, just dump a template there
    if create_template:
        if not os.path.exists(userconfig):
            defaultconfig_file = ""
            if os.path.exists(defaultconfig1):
                defaultconfig_file = defaultconfig1
            elif os.path.exists(defaultconfig2):
                defaultconfig_file = defaultconfig2
            if defaultconfig_file != "":
                in_file = open(defaultconfig_file,'r')
                out_file = open(userconfig,'w')
                lines = in_file.readlines()
                try: #Pop the first 2 lines
                    lines.pop(0)
                    lines.pop(0)
                except:
                    pass
                for line in lines:
                    if line.startswith('#') or line.startswith('[') or line.strip() == "" :
                        out_file.write(line)
                    else:
                        out_file.write('#' + line)
                in_file.close()
                out_file.close()
    #Return the config parser
    return getConfigParser._config

if __name__ == "__main__":
    import sys
    config = getConfigParser()
    config.write(sys.stdout)
