#!/usr/bin/python3
# -*- coding: utf-8 -*-
# kate: space-indent on; indent-width 4; replace-tabs on; indent-mode python; remove-trailing-space modified;
# vim: expandtab ts=4

############################################################################
#   Copyright © 2016 José Manuel Santamaría Lema <panfaust@gmail.com>      #
#                                                                          #
#   This program is free software; you can redistribute it and/or modify   #
#   it under the terms of the GNU General Public License as published by   #
#   the Free Software Foundation; either version 2 of the License, or      #
#   (at your option) any later version.                                    #
############################################################################

import os
import sys
import json

from jsmin import jsmin

from libka.ka_print import *
from libka.ka_configuration import *


# Return the current data files path
def getDataFilesPath():
    ka_config = getConfigParser()
    data_files_path = ka_config['global']['ka-metatadata-path']
    data_files_path = os.path.expanduser(data_files_path)
    if not os.path.exists(data_files_path):
        ka_print_error('ERROR: metadata repository not found at %s'
            % data_files_path)
        ka_print_plain('You must clone the Kubuntu Automation metadata repository in %s'
            % data_files_path)
        ka_metatadata_git_https = 'https://git.launchpad.net/~kubuntu-packagers/ka/+git/ka-metadata'
        ka_metatadata_git_ssh = 'git+ssh://git.launchpad.net/~kubuntu-packagers/ka/+git/ka-metadata'
        ka_print_plain('You can do that with git clone %s\nOR git clone %s'
            % (ka_metatadata_git_https, ka_metatadata_git_ssh) )
        sys.exit(1)
    return data_files_path

# Return a list of packages, stripping comments starting with '#'
def readPackagesFile(file_name,catch_exceptions=True):
    #Find out the data files path
    data_files_path = getDataFilesPath()
    #Load the data file
    file_path = os.path.join(data_files_path,file_name)
    try:
        #Read file lines
        f = open(file_path, "r")
        packages = f.readlines()
        f.close()
        #Filter out comments
        packages = map(lambda line: line.split('#')[0].strip("\r\n\t "), packages)
        packages = filter(lambda line: line and not line.startswith("#"), packages)
        #Remove comments to the left of the package name
    except Exception as e:
        if catch_exceptions:
            ka_print_error("Error loading packages file %s" % file_path)
            print(e)
            sys.exit(1)
        else:
            return []

    return list(packages)

#Return a JSON map with the file contents, stripping comments
#Comments may start with '//'
def readJsonDataFile(file_name,catch_exceptions=True):
    #Find out the data files path
    data_files_path = getDataFilesPath()
    #Load the data file
    file_path = data_files_path + '/' + file_name
    try:
        f = open(file_path,'r')
        json_string = jsmin(f.read())
        f.close()
        result = json.loads(json_string)
    except Exception as e:
        if catch_exceptions:
            ka_print_error("Error loading JSON file %s" % file_path)
            print(e)
            sys.exit(1)
        else:
            return ""
    return result


if __name__ == "__main__":
    print("Data path: " + getDataFilesPath())
    json_data = readJsonDataFile("versions.json")
    print(json_data)
