#!/usr/bin/python3
# -*- coding: utf-8 -*-
# kate: space-indent on; indent-width 4; replace-tabs on; indent-mode python; remove-trailing-space modified;
# vim: expandtab ts=4

############################################################################
#   Copyright © 2016 José Manuel Santamaría Lema <panfaust@gmail.com>      #
#                                                                          #
#   This program is free software; you can redistribute it and/or modify   #
#   it under the terms of the GNU General Public License as published by   #
#   the Free Software Foundation; either version 2 of the License, or      #
#   (at your option) any later version.                                    #
############################################################################

from termcolor import cprint
import sys
import os

from libka.ka_configuration import *

this = sys.modules[__name__]
this._ka_log_file = None

def ka_enable_logs(file_name):
    global _ka_log_file
    try:
        directory = os.path.dirname(file_name)
        if not os.path.exists(directory): #Make sure the directory exists
            os.makedirs(directory)
        _ka_log_file = open(file_name,'w')
    except Exception as e:
        ka_print_error("Error opening log file %s" % file_name)
        ka_print_error(str(e))
        sys.exit(1)

def ka_disable_logs():
    global _ka_log_file
    _ka_log_file = None

def ka_print_plain(string,end='\n'):
    print(string,end=end)
    if _ka_log_file != None:
        _ka_log_file.write(string + end)
        _ka_log_file.flush()

def ka_print_error(string,end='\n'):
    config = getConfigParser()
    if config['global'].getboolean('colors'):
        cprint(string, 'red', end=end)
    else:
        print(string,end=end)
    if _ka_log_file != None:
        _ka_log_file.write(string + end)
        _ka_log_file.flush()

def ka_print_warning(string,end='\n'):
    config = getConfigParser()
    if config['global'].getboolean('colors'):
        cprint(string, 'yellow', end=end)
    else:
        print(string, end=end)
    if _ka_log_file != None:
        _ka_log_file.write(string + end)
        _ka_log_file.flush()

def ka_print_info(string,end='\n'):
    config = getConfigParser()
    if config['global'].getboolean('colors'):
        cprint(string, 'blue', end=end)
    else:
        print(string, end=end)
    if _ka_log_file != None:
        _ka_log_file.write(string + end)
        _ka_log_file.flush()

def ka_print_good_stuff(string,end='\n'):
    config = getConfigParser()
    if config['global'].getboolean('colors'):
        cprint(string, 'green', end=end)
    else:
        print(string, end=end)
    if _ka_log_file != None:
        _ka_log_file.write(string + end)
        _ka_log_file.flush()

if __name__ == "__main__":
    ka_print_error("Error text")
    ka_print_warning("Warning text")
    ka_print_info("Info text")
    ka_print_good_stuff("Good stuff text")
