#!/usr/bin/python3
# -*- coding: utf-8 -*-
# kate: space-indent on; indent-width 4; replace-tabs on; indent-mode python; remove-trailing-space modified;
# vim: expandtab ts=4

############################################################################
#   Copyright © 2015-2016 José Manuel Santamaría Lema <panfaust@gmail.com> #
#                                                                          #
#   This program is free software; you can redistribute it and/or modify   #
#   it under the terms of the GNU General Public License as published by   #
#   the Free Software Foundation; either version 2 of the License, or      #
#   (at your option) any later version.                                    #
############################################################################

import json
import os
import sys
import subprocess
import re

from ftplib import FTP
from io import StringIO

from libka.ka_data_utils import *

# ReleaseType example:
# ["frameworks","plasma","applications"]
# it would get a map of everything of frameworks/plasma/applications
def getFtpVersionMap(releaseType):
    #Populate and return the map
    packageVersionMap = {}
    #Find out the version
    rt_versions_map = readJsonDataFile("versions.json")
    version = rt_versions_map[releaseType]
    #If the result is cached return it
    cache_dir = "~/.kubuntu-automation/cache/kde_ftp/"
    cache_dir = os.path.expanduser(cache_dir)
    cache_file_path = cache_dir + releaseType + "-" + version + ".json"
    try:
        fp = open(cache_file_path, 'r')
        packageVersionMap = json.load(fp)
        return packageVersionMap
    except:
        pass
    #Find out which subdirectories we have to inspeact in the ftp
    ftp_subdirs = []
    if releaseType == "frameworks":
        ftp_subdirs = ["","portingAids"]
    elif releaseType == "plasma":
        ftp_subdirs = [""]
    elif releaseType == "applications":
        ftp_subdirs = ["src"]
    elif releaseType == "qt":
        ftp_subdirs = [""]
    #Find out the stability
    versionParts = version.split(".")
    lastDigit = int(versionParts[-1])
    if lastDigit >= 80:
        stability = "unstable"
    else:
        stability = "stable"
    #Inspect the ftp
    for subdir in ftp_subdirs:
        if releaseType != "qt":
            kde_sftp_site = "racnoss.kde.org"
            ftp_command = ["sftp", "-b", "-", "%s:%s/%s/%s/%s"
                % (kde_sftp_site, stability, releaseType, version, subdir)]
            devnull = open(os.devnull,'w')
            p = subprocess.Popen(ftp_command, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=devnull)
            output, _ = p.communicate(bytes("ls *xz", 'utf-8'))
            if p.returncode != 0:
                ka_print_warning("WARNING: Accessing FTP listing via plain FTP.")
                ka_print_warning("Maybe you want to configure your ssh config to access %s?" % kde_sftp_site)
                kde_ftp = "ftp.pbone.net"
                kde_ftp_dir = "pub/kde"
                ftp = FTP(kde_ftp)
                try:
                    ftp.login()
                except:
                    ka_print_error("Can't login to %s" % kde_ftp)
                    sys.exit(1)
                try:
                    ftp.cwd(kde_ftp_dir)
                except:
                    ka_print_error("Can't access %s directory on %s" % (kde_ftp_dir,kde_ftp))
                    sys.exit(1)
                kde_ftp_subdir = "%s/%s/%s/%s" % (stability, releaseType, version, subdir)
                try:
                    ftp.cwd(kde_ftp_subdir)
                except:
                    ka_print_error("Can't access %s directory on %s" % (kde_ftp_subdir,kde_ftp))
                    sys.exit(1)
                output = StringIO()
                callback = lambda s: output.write(s+'\n')
                ftp.retrlines("NLST *.xz",callback)
                output = bytes(output.getvalue(),'utf-8')
        else:
            ftp = FTP("ftp.mirrorservice.org")
            ftp.login()
            version_short = versionParts[0] + "." + versionParts[1]
            ftp.cwd("sites/download.qt-project.org/official_releases/qt/" + version_short + "/" + version + "/submodules/")
            output = StringIO()
            callback = lambda s: output.write(s+'\n')
            ftp.retrlines("NLST *.xz",callback)
            output = bytes(output.getvalue(),'utf-8')
        #Fill the map inspecting the "ls" results from the ftp
        for line in output.splitlines():
            line = line.decode('utf-8')
            match = re.search(r'([a-zA-Z0-9\-]+)-' + '([\d.]*)' + r'\.tar\.', line)
            if match:
                package = match.group(1)
                package_version = match.group(2)
                packageVersionMap[package] = package_version
    #Store the result in cache
    try:
        os.makedirs(cache_dir)
    except:
        pass
    cache_file = open(cache_file_path, 'w')
    json.dump(packageVersionMap, cache_file)
    cache_file.close()
    #Return the resulting map
    return packageVersionMap

